
API documentation
=================

Echelle plotting
----------------

.. automodule:: echelle.echelle
   :members:

Interactive echelle
-------------------

.. automodule:: echelle.interact
   :members:

Utilities
---------

.. automodule:: echelle.utils
   :members: